@@ -202,7 +202,9 @@
 			    `((,@props ,(concat name "-down.xpm"))))
 		      disabled (wl-e21-find-image
 				`((,@props ,(concat name "-disabled.xpm")))))
-		(set icon (vector down up disabled disabled)))
+		(if (and down disabled)
+		    (set icon (vector down up disabled disabled))
+		  (set icon up)))
 	    (setq bar nil
 		  success nil))))
       success)))
@@ -657,7 +659,7 @@ Special commands:
   (define-key wl-draft-mode-map "\C-c\C-j" 'wl-template-select)
   (define-key wl-draft-mode-map "\C-c\C-p" 'wl-draft-preview-message)
   (define-key wl-draft-mode-map "\C-c\C-a" 'wl-addrmgr)
-;;  (define-key wl-draft-mode-map "\C-x\C-s" 'wl-draft-save)
+;;;  (define-key wl-draft-mode-map "\C-x\C-s" 'wl-draft-save)
   (define-key wl-draft-mode-map "\C-xk"    'wl-draft-mimic-kill-buffer)
   (define-key wl-draft-mode-map "\C-c\C-d" 'wl-draft-elide-region)
   (define-key wl-draft-mode-map "\C-a" 'wl-draft-beginning-of-line)
@@ -666,7 +668,7 @@ Special commands:
 
 (defun wl-draft-overload-functions ()
   (wl-mode-line-buffer-identification)
-;;  (local-set-key "\C-c\C-s" 'wl-draft-send);; override
+;;;  (local-set-key "\C-c\C-s" 'wl-draft-send) ; override
   (wl-e21-setup-draft-toolbar)
   (wl-draft-overload-menubar))
 
